@@ -2,7 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019      The Fluent Bit Authors
+ *  Copyright (C) 2019-2020 The Fluent Bit Authors
  *  Copyright (C) 2015-2018 Treasure Data Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
@@ -41,7 +41,8 @@ struct flb_hs_buf {
 struct flb_hs {
     mk_ctx_t *ctx;             /* Monkey HTTP Context */
     int vid;                   /* Virtual Host ID     */
-    int qid;                   /* Message Queue ID    */
+    int qid_metrics;           /* Metrics Message Queue ID    */
+    int qid_storage;           /* Storage Message Queue ID    */
 
     pthread_t tid;             /* Server Thread */
     struct flb_config *config; /* Fluent Bit context */
@@ -53,7 +54,9 @@ struct flb_hs {
 
 struct flb_hs *flb_hs_create(const char *listen, const char *tcp_port,
                              struct flb_config *config);
-int flb_hs_push_metrics(struct flb_hs *hs, void *data, size_t size);
+int flb_hs_push_pipeline_metrics(struct flb_hs *hs, void *data, size_t size);
+int flb_hs_push_storage_metrics(struct flb_hs *hs, void *data, size_t size);
+
 int flb_hs_destroy(struct flb_hs *ctx);
 int flb_hs_start(struct flb_hs *hs);
 
