@@ -36,7 +36,7 @@
 #include "rdkafka_transport_int.h"
 #include "rdkafka_cert.h"
 
-#ifdef _MSC_VER
+#ifdef _WIN32
 #pragma comment (lib, "crypt32.lib")
 #endif
 
@@ -81,7 +81,7 @@ void rd_kafka_transport_ssl_close (rd_kafka_transport_t *rktrans) {
 static RD_INLINE void
 rd_kafka_transport_ssl_clear_error (rd_kafka_transport_t *rktrans) {
         ERR_clear_error();
-#ifdef _MSC_VER
+#ifdef _WIN32
         WSASetLastError(0);
 #else
         rd_set_errno(0);
@@ -130,7 +130,11 @@ static char *rd_kafka_ssl_error (rd_kafka_t *rk, rd_kafka_broker_t *rkb,
         int line, flags;
         int cnt = 0;
 
-        while ((l = ERR_get_error_line_data(&file, &line, &data, &flags)) != 0) {
+        if (!rk)
+                rk = rkb->rkb_rk;
+
+        while ((l = ERR_get_error_line_data(&file, &line,
+                                            &data, &flags)) != 0) {
                 char buf[256];
 
                 if (cnt++ > 0) {
@@ -143,13 +147,25 @@ static char *rd_kafka_ssl_error (rd_kafka_t *rk, rd_kafka_broker_t *rkb,
 
                 ERR_error_string_n(l, buf, sizeof(buf));
 
-                rd_snprintf(errstr, errstr_size, "%s:%d: %s: %s",
-                            file, line, buf, (flags & ERR_TXT_STRING) ? data : "");
+                if (!(flags & ERR_TXT_STRING) || !data || !*data)
+                        data = NULL;
 
+                /* Include openssl file:line if debugging is enabled */
+                if (rk->rk_conf.log_level >= LOG_DEBUG)
+                        rd_snprintf(errstr, errstr_size, "%s:%d: %s%s%s",
+                                    file, line, buf,
+                                    data ? ": " : "",
+                                    data ? data : "");
+                else
+                        rd_snprintf(errstr, errstr_size, "%s%s%s",
+                                    buf,
+                                    data ? ": " : "",
+                                    data ? data : "");
         }
 
         if (cnt == 0)
-                rd_snprintf(errstr, errstr_size, "No error");
+                rd_snprintf(errstr, errstr_size,
+                            "No further error information available");
 
         return errstr;
 }
@@ -592,11 +608,36 @@ int rd_kafka_transport_ssl_handshake (rd_kafka_transport_t *rktrans) {
         } else if (rd_kafka_transport_ssl_io_update(rktrans, r,
                                                     errstr,
                                                     sizeof(errstr)) == -1) {
+                const char *extra = "";
+
+                if (strstr(errstr, "unexpected message"))
+                        extra = ": client SSL authentication might be "
+                                "required (see ssl.key.location and "
+                                "ssl.certificate.location and consult the "
+                                "broker logs for more information)";
+                else if (strstr(errstr, "tls_process_server_certificate:"
+                                "certificate verify failed") ||
+                         strstr(errstr, "get_server_certificate:"
+                                "certificate verify failed"))
+                        extra = ": broker certificate could not be verified, "
+                                "verify that ssl.ca.location is correctly "
+                                "configured or root CA certificates are "
+                                "installed"
+#ifdef __APPLE__
+                                " (brew install openssl)"
+#elif defined(_WIN32)
+                                " (add broker's CA certificate to the Windows "
+                                "Root certificate store)"
+#else
+                                " (install ca-certificates package)"
+#endif
+                                ;
+                else if (!strcmp(errstr, "Disconnected"))
+                        extra = ": connecting to a PLAINTEXT broker listener?";
+
                 rd_kafka_broker_fail(rkb, LOG_ERR, RD_KAFKA_RESP_ERR__SSL,
                                      "SSL handshake failed: %s%s", errstr,
-                                     strstr(errstr, "unexpected message") ?
-                                     ": client authentication might be "
-                                     "required (see broker log)" : "");
+                                     extra);
                 return -1;
         }
 
@@ -648,7 +689,7 @@ static X509 *rd_kafka_ssl_X509_from_string (rd_kafka_t *rk, const char *str) {
 }
 
 
-#if _MSC_VER
+#ifdef _WIN32
 
 /**
  * @brief Attempt load CA certificates from the Windows Certificate Root store.
@@ -774,9 +815,10 @@ static int rd_kafka_ssl_probe_and_set_default_ca_location (rd_kafka_t *rk,
         int i;
 
         for (i = 0 ; (path = paths[i]) ; i++) {
+                struct stat st;
                 rd_bool_t is_dir;
                 int r;
-                struct stat st;
+
                 if (stat(path, &st) != 0)
                         continue;
 
@@ -864,7 +906,7 @@ static int rd_kafka_ssl_set_certs (rd_kafka_t *rk, SSL_CTX *ctx,
                 }
 
         } else {
-#if _MSC_VER
+#ifdef _WIN32
                 /* Attempt to load CA root certificates from the
                  * Windows crypto Root cert store. */
                 r = rd_kafka_ssl_win_load_root_certs(rk, ctx);
@@ -1288,7 +1330,7 @@ rd_kafka_transport_ssl_lock_cb (int mode, int i, const char *file, int line) {
 #endif
 
 static RD_UNUSED unsigned long rd_kafka_transport_ssl_threadid_cb (void) {
-#ifdef _MSC_VER
+#ifdef _WIN32
         /* Windows makes a distinction between thread handle
          * and thread id, which means we can't use the
          * thrd_current() API that returns the handle. */
