@@ -2,7 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019      The Fluent Bit Authors
+ *  Copyright (C) 2019-2020 The Fluent Bit Authors
  *  Copyright (C) 2015-2018 Treasure Data Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,6 +23,7 @@
 
 #include "uptime.h"
 #include "metrics.h"
+#include "storage.h"
 #include "plugins.h"
 
 int api_v1_registration(struct flb_hs *hs)
@@ -31,5 +32,9 @@ int api_v1_registration(struct flb_hs *hs)
     api_v1_metrics(hs);
     api_v1_plugins(hs);
 
+    if (hs->config->storage_metrics == FLB_TRUE) {
+        api_v1_storage_metrics(hs);
+    }
+
     return 0;
 }
